@@ -31,7 +31,7 @@ class Gtk::MikutterWindow < Gtk::Window
   end
 
   def add_postbox(i_postbox)
-    postbox = Gtk::PostBox.new(i_postbox.poster || Gtk::PostBox::PostToPrimaryService.new, {postboxstorage: @postboxes, delegate_other: true}.merge(i_postbox.options||{}))
+    postbox = Gtk::PostBox.new({postboxstorage: @postboxes, delegate_other: true}.merge(i_postbox.options||{}))
     @postboxes.pack_start(postbox)
     set_focus(postbox.post)
     postbox.no_show_all = false
@@ -51,7 +51,6 @@ class Gtk::MikutterWindow < Gtk::Window
   # Gtk::Statusbar
   def create_statusbar
     statusbar = Gtk::Statusbar.new
-    notice "statusbar: context id: #{statusbar.get_context_id("system")}"
     statusbar.push(statusbar.get_context_id("system"), @plugin._("Statusbar default message"))
     @statusbar = statusbar.closeup(status_button(Gtk::HBox.new)) end
 
